*************
Python module
*************

Overview
========

.. autosummary::

    conda_envfile.parse_file
    conda_envfile.remove
    conda_envfile.unique

conda_envfile
=============

.. automodule:: conda_envfile
  :members:
